=== modified file 'drizzled/error.h'
--- drizzled/error.h	2009-01-28 02:39:29 +0000
+++ drizzled/error.h	2009-02-11 02:30:38 +0000
@@ -720,7 +720,7 @@
   ER_INVALID_NEGATIVE_ARGUMENT,
   ER_ARGUMENT_OUT_OF_RANGE,
   ER_INVALID_TIME_VALUE,
-  ER_ERROR_LAST= ER_ARGUMENT_OUT_OF_RANGE
+  ER_ERROR_LAST= ER_INVALID_TIME_VALUE
 };
 
 #ifdef  __cplusplus

=== modified file 'drizzled/field/date.cc'
--- drizzled/field/date.cc	2009-01-23 06:03:42 +0000
+++ drizzled/field/date.cc	2009-02-11 02:30:38 +0000
@@ -19,11 +19,12 @@
  */
 
 
-#include <drizzled/server_includes.h>
-#include <drizzled/field/date.h>
-#include <drizzled/error.h>
-#include <drizzled/table.h>
-#include <drizzled/session.h>
+#include "drizzled/server_includes.h"
+#include "drizzled/field/date.h"
+#include "drizzled/error.h"
+#include "drizzled/table.h"
+#include "drizzled/temporal.h"
+#include "drizzled/session.h"
 
 #include CMATH_H
 
@@ -59,6 +60,7 @@
                          uint32_t len,
                          const CHARSET_INFO * const )
 {
+#ifdef NOTDEFINED
   long tmp;
   DRIZZLE_TIME l_time;
   int error;
@@ -88,10 +90,25 @@
                          from, len, DRIZZLE_TIMESTAMP_DATE, 1);
 
   int3store(ptr, tmp);
-  return error;
+#endif /* NOTDEFINED */
+  /* 
+   * Try to create a DateTime from the supplied string.  Throw an error
+   * if unable to create a valid DateTime.  A DateTime is used so that
+   * automatic conversion from the higher-storage DateTime can be used
+   * and matches on datetime format strings can occur.
+   */
+  drizzled::DateTime temporal;
+  if (! temporal.from_string(from, (size_t) len))
+  {
+    my_error(ER_INVALID_DATETIME_VALUE, MYF(ME_FATALERROR), from);
+    return 2;
+  }
+  /* Create the stored integer format. @TODO This should go away. Should be up to engine... */
+  uint32_t int_value= (temporal.years() * 16 * 32) + (temporal.months() * 32) + temporal.days();
+  int3store(ptr, int_value);
+  return 0;
 }
 
-
 int Field_date::store(double nr)
 {
   if (nr < 0.0 || nr > 99991231235959.0)

=== modified file 'drizzled/temporal_format.cc'
--- drizzled/temporal_format.cc	2009-02-10 02:29:23 +0000
+++ drizzled/temporal_format.cc	2009-02-11 02:30:38 +0000
@@ -28,16 +28,15 @@
  * Implementation of the server's date and time string matching utility.
  */
 
+#include <string> /** C++ string class used */
+#include <string.h>
+#include <vector>
+#include <pcre.h>
 
 #include "drizzled/global.h"
 #include "drizzled/temporal_format.h"
 #include "drizzled/temporal.h"
 
-#include <string> /** C++ string class used */
-#include <string.h>
-#include <vector>
-#include PCRE_HEADER
-
 namespace drizzled
 {
 
@@ -198,7 +197,7 @@
 
 } /* end namespace drizzled */
 
-#define COUNT_KNOWN_FORMATS 14
+#define COUNT_KNOWN_FORMATS 16
 
 struct temporal_format_args
 {
@@ -236,8 +235,10 @@
 , {"^(\\d{2})[-/.]*(\\d{2})[-/.]*(\\d{4})$", 3, 1, 2, 0, 0, 0, 0, 0} /* MM[-/.]DD[-/.]YYYY (US common format)*/
 , {"^(\\d{2})[-/.]*(\\d{2})[-/.]*(\\d{2})$", 1, 2, 3, 0, 0, 0, 0, 0} /* YY[-/.]MM[-/.]DD */
 , {"^(\\d{2})[-/.]*(\\d{1,2})[-/.]*(\\d{1,2})$", 1, 2, 3, 0, 0, 0, 0, 0} /* YY[-/.][M]M[-/.][D]D */
+, {"^(\\d{4})[-/.]*(\\d{1,2})[-/.]*(\\d{1,2})$", 1, 2, 3, 0, 0, 0, 0, 0} /* YYYY[-/.][M]M[-/.][D]D */
 , {"^(\\d{2}):*(\\d{2}):*(\\d{2})\\.(\\d{1,6})$", 0, 0, 0, 1, 2, 3, 4, 0} /* HHmmSS.uuuuuu, HH:mm:SS.uuuuuu */
 , {"^(\\d{1,2}):*(\\d{2}):*(\\d{2})$", 0, 0, 0, 1, 2, 3, 0, 0} /* [H]HmmSS, [H]H:mm:SS */
+, {"^(\\d{1,2}):(\\d{1,2}):(\\d{1,2})$", 0, 0, 0, 1, 2, 3, 0, 0} /* [H]H:[m]m:[S]S */
 , {"^(\\d{1,2}):*(\\d{2})$", 0, 0, 0, 0, 1, 2, 0, 0} /* [m]mSS, [m]m:SS */
 , {"^(\\d{1,2})$", 0, 0, 0, 0, 0, 1, 0, 0} /* SS, S */
 , {"^(\\d{1,2})\\.(\\d{1,6})$", 0, 0, 0, 0, 0, 1, 2, 0} /* [S]S.uuuuuu */

=== modified file 'po/POTFILES.in'
--- po/POTFILES.in	2009-02-08 08:27:20 +0000
+++ po/POTFILES.in	2009-02-11 02:30:38 +0000
@@ -38,10 +38,10 @@
 mysys/errors.cc
 mysys/my_error.cc
 mysys/my_getopt.cc
-mysys/thr_alarm.cc
 plugin/errmsg_stderr/errmsg_stderr.cc
 plugin/logging_query/logging_query.cc
 plugin/logging_syslog/logging_syslog.cc
+plugin/multi_thread/multi_thread.cc
 plugin/pool_of_threads/pool_of_threads.cc
 plugin/pool_of_threads/session_scheduler.cc
 plugin/replicator/replicator.cc

=== modified file 'tests/include/common-tests.inc'
--- tests/include/common-tests.inc	2008-10-20 01:46:44 +0000
+++ tests/include/common-tests.inc	2009-02-11 02:30:38 +0000
@@ -1770,7 +1770,7 @@
   aufnr int NOT NULL default '0',
   username varchar(50) NOT NULL default '',
   hdl_nr int NOT NULL default '0',
-  eintrag date NOT NULL default '0000-00-00',
+  eintrag date NULL,
   st_klasse varchar(40) NOT NULL default '',
   st_wert varchar(40) NOT NULL default '',
   st_zusatz varchar(40) NOT NULL default '',

=== modified file 'tests/r/alias.result'
--- tests/r/alias.result	2009-01-06 14:23:31 +0000
+++ tests/r/alias.result	2009-02-11 02:30:38 +0000
@@ -5,7 +5,7 @@
 aufnr int NOT NULL default '0',
 username varchar(50) NOT NULL default '',
 hdl_nr int NOT NULL default '0',
-eintrag date NOT NULL default '0000-00-00',
+eintrag date NOT NULL, 
 st_klasse varchar(40) NOT NULL default '',
 st_wert varchar(40) NOT NULL default '',
 st_zusatz varchar(40) NOT NULL default '',

=== modified file 'tests/r/date_formats.result'
--- tests/r/date_formats.result	2009-01-29 22:22:50 +0000
+++ tests/r/date_formats.result	2009-02-11 02:30:38 +0000
@@ -456,54 +456,6 @@
 14
 14
 drop table t1;
-select str_to_date("2003-....01ABCD-02 10:11:12.0012", "%Y-%.%m%@-%d %H:%i:%S.%f") as a;
-a
-2003-01-02 10:11:12.001200
-create table t1 select str_to_date("2003-01-02 10:11:12.0012", "%Y-%m-%d %H:%i:%S.%f") as f1,
-str_to_date("10:11:12.0012", "%H:%i:%S.%f") as f2,
-str_to_date("2003-01-02", "%Y-%m-%d") as f3,
-str_to_date("02", "%d") as f4, str_to_date("02 10", "%d %H") as f5;
-describe t1;
-Field	Type	Null	Key	Default	Extra
-f1	datetime	YES		NULL	
-f2	time	YES		NULL	
-f3	date	YES		NULL	
-f4	date	YES		NULL	
-f5	time	YES		NULL	
-select * from t1;
-f1	f2	f3	f4	f5
-2003-01-02 10:11:12	10:11:12	2003-01-02	0000-00-02	58:00:00
-drop table t1;
-create table t1 select "02 10" as a, "%d %H" as b;
-select str_to_date(a,b) from t1;
-str_to_date(a,b)
-0000-00-02 10:00:00
-create table t2 select str_to_date(a,b) from t1;
-describe t2;
-Field	Type	Null	Key	Default	Extra
-str_to_date(a,b)	datetime	YES		NULL	
-select str_to_date("2003-01-02 10:11:12.0012", "%Y-%m-%d %H:%i:%S.%f") as f1,
-str_to_date("2003-01-02 10:11:12.0012", "%Y-%m-%d %H:%i:%S") as f2,
-str_to_date("2003-01-02", "%Y-%m-%d") as f3,
-str_to_date("02 10:11:12", "%d %H:%i:%S.%f") as f4,
-str_to_date("02 10:11:12", "%d %H:%i:%S") as f5,
-str_to_date("02 10", "%d %f") as f6;
-f1	f2	f3	f4	f5	f6
-2003-01-02 10:11:12.001200	2003-01-02 10:11:12	2003-01-02	58:11:12	58:11:12	48:00:00.100000
-Warnings:
-Warning	1292	Truncated incorrect datetime value: '2003-01-02 10:11:12.0012'
-drop table t1, t2;
-select str_to_date("2003-01-02 10:11:12.0012ABCD", "%Y-%m-%d %H:%i:%S.%f") as f1,
-addtime("-01:01:01.01 GGG", "-23:59:59.1") as f2,
-microsecond("1997-12-31 23:59:59.01XXXX") as f3;
-ERROR HY000: Received an invalid datetime value '1997-12-31 23:59:59.01XXXX'.
-select str_to_date("2003-04-05  g", "%Y-%m-%d") as f1,
-str_to_date("2003-04-05 10:11:12.101010234567", "%Y-%m-%d %H:%i:%S.%f") as f2;
-f1	f2
-2003-04-05	2003-04-05 10:11:12.101010
-Warnings:
-Warning	1292	Truncated incorrect date value: '2003-04-05  g'
-Warning	1292	Truncated incorrect datetime value: '2003-04-05 10:11:12.101010234567'
 create table t1 (f1 datetime);
 insert into t1 (f1) values ("2005-01-01");
 insert into t1 (f1) values ("2005-02-01");

=== modified file 'tests/r/distinct.result'
--- tests/r/distinct.result	2008-12-06 22:41:03 +0000
+++ tests/r/distinct.result	2009-02-11 02:30:38 +0000
@@ -404,11 +404,11 @@
 drop table t1,t2;
 CREATE TABLE t1 (privatemessageid int NOT NULL auto_increment,  folderid int NOT NULL default '0',  userid int NOT NULL default '0',  touserid int NOT NULL default '0',  fromuserid int NOT NULL default '0',  title varchar(250) NOT NULL default '',  message mediumtext NOT NULL,  dateline int NOT NULL default '0',  showsignature int NOT NULL default '0',  iconid int NOT NULL default '0',  messageread int NOT NULL default '0',  readtime int NOT NULL default '0',  receipt int NOT NULL default '0',  deleteprompt int NOT NULL default '0',  multiplerecipients int NOT NULL default '0',  PRIMARY KEY  (privatemessageid),  KEY userid (userid)) ENGINE=MyISAM;
 INSERT INTO t1 VALUES (128,0,33,33,8,':D','',996121863,1,0,2,996122850,2,0,0);
-CREATE TABLE t2 (userid int NOT NULL auto_increment,  usergroupid int NOT NULL default '0',  username varchar(50) NOT NULL default '',  password varchar(50) NOT NULL default '',  email varchar(50) NOT NULL default '',  styleid int NOT NULL default '0',  parentemail varchar(50) NOT NULL default '',  coppauser int NOT NULL default '0',  homepage varchar(100) NOT NULL default '',  icq varchar(20) NOT NULL default '',  aim varchar(20) NOT NULL default '',  yahoo varchar(20) NOT NULL default '',  signature mediumtext NOT NULL,  adminemail int NOT NULL default '0',  showemail int NOT NULL default '0',  invisible int NOT NULL default '0',  usertitle varchar(250) NOT NULL default '',  customtitle int NOT NULL default '0',  joindate int NOT NULL default '0',  cookieuser int NOT NULL default '0',  daysprune int NOT NULL default '0',  lastvisit int NOT NULL default '0',  lastactivity int NOT NULL default '0',  lastpost int NOT NULL default '0',  posts int NOT NULL default '0',  timezoneoffset varchar(4) NOT NULL default '',  emailnotification int NOT NULL default '0',  buddylist mediumtext NOT NULL,  ignorelist mediumtext NOT NULL,  pmfolders mediumtext NOT NULL,  receivepm int NOT NULL default '0',  emailonpm int NOT NULL default '0',  pmpopup int NOT NULL default '0',  avatarid int NOT NULL default '0',  avatarrevision int NOT NULL default '0',  options int NOT NULL default '15',  birthday date NOT NULL default '0000-00-00',  maxposts int NOT NULL default '-1',  startofweek int NOT NULL default '1',  ipaddress varchar(20) NOT NULL default '',  referrerid int NOT NULL default '0',  nosessionhash int NOT NULL default '0',  autorefresh int NOT NULL default '-1',  messagepopup int NOT NULL default '0',  inforum int NOT NULL default '0',  ratenum int NOT NULL default '0',  ratetotal int NOT NULL default '0',  allowrate int NOT NULL default '1',  PRIMARY KEY  (userid),  KEY usergroupid (usergroupid),  KEY username (username),  KEY inforum (inforum)) ENGINE=MyISAM;
-INSERT INTO t2 VALUES (33,6,'Kevin','0','kevin@stileproject.com',1,'',0,'http://www.stileproject.com','','','','',1,1,0,'Administrator',0,996120694,1,-1,1030996168,1031027028,1030599436,36,'-6',0,'','','',1,0,1,0,0,15,'0000-00-00',-1,1,'64.0.0.0',0,1,-1,0,0,4,19,1);
+CREATE TABLE t2 (userid int NOT NULL auto_increment,  usergroupid int NOT NULL default '0',  username varchar(50) NOT NULL default '',  password varchar(50) NOT NULL default '',  email varchar(50) NOT NULL default '',  styleid int NOT NULL default '0',  parentemail varchar(50) NOT NULL default '',  coppauser int NOT NULL default '0',  homepage varchar(100) NOT NULL default '',  icq varchar(20) NOT NULL default '',  aim varchar(20) NOT NULL default '',  yahoo varchar(20) NOT NULL default '',  signature mediumtext NOT NULL,  adminemail int NOT NULL default '0',  showemail int NOT NULL default '0',  invisible int NOT NULL default '0',  usertitle varchar(250) NOT NULL default '',  customtitle int NOT NULL default '0',  joindate int NOT NULL default '0',  cookieuser int NOT NULL default '0',  daysprune int NOT NULL default '0',  lastvisit int NOT NULL default '0',  lastactivity int NOT NULL default '0',  lastpost int NOT NULL default '0',  posts int NOT NULL default '0',  timezoneoffset varchar(4) NOT NULL default '',  emailnotification int NOT NULL default '0',  buddylist mediumtext NOT NULL,  ignorelist mediumtext NOT NULL,  pmfolders mediumtext NOT NULL,  receivepm int NOT NULL default '0',  emailonpm int NOT NULL default '0',  pmpopup int NOT NULL default '0',  avatarid int NOT NULL default '0',  avatarrevision int NOT NULL default '0',  options int NOT NULL default '15',  birthday date NULL,  maxposts int NOT NULL default '-1',  startofweek int NOT NULL default '1',  ipaddress varchar(20) NOT NULL default '',  referrerid int NOT NULL default '0',  nosessionhash int NOT NULL default '0',  autorefresh int NOT NULL default '-1',  messagepopup int NOT NULL default '0',  inforum int NOT NULL default '0',  ratenum int NOT NULL default '0',  ratetotal int NOT NULL default '0',  allowrate int NOT NULL default '1',  PRIMARY KEY  (userid),  KEY usergroupid (usergroupid),  KEY username (username),  KEY inforum (inforum)) ENGINE=MyISAM;
+INSERT INTO t2 VALUES (33,6,'Kevin','0','kevin@stileproject.com',1,'',0,'http://www.stileproject.com','','','','',1,1,0,'Administrator',0,996120694,1,-1,1030996168,1031027028,1030599436,36,'-6',0,'','','',1,0,1,0,0,15,NULL,-1,1,'64.0.0.0',0,1,-1,0,0,4,19,1);
 SELECT DISTINCT t1.*, t2.* FROM t1 LEFT JOIN t2 ON (t2.userid = t1.touserid);
 privatemessageid	folderid	userid	touserid	fromuserid	title	message	dateline	showsignature	iconid	messageread	readtime	receipt	deleteprompt	multiplerecipients	userid	usergroupid	username	password	email	styleid	parentemail	coppauser	homepage	icq	aim	yahoo	signature	adminemail	showemail	invisible	usertitle	customtitle	joindate	cookieuser	daysprune	lastvisit	lastactivity	lastpost	posts	timezoneoffset	emailnotification	buddylist	ignorelist	pmfolders	receivepm	emailonpm	pmpopup	avatarid	avatarrevision	options	birthday	maxposts	startofweek	ipaddress	referrerid	nosessionhash	autorefresh	messagepopup	inforum	ratenum	ratetotal	allowrate
-128	0	33	33	8	:D		996121863	1	0	2	996122850	2	0	0	33	6	Kevin	0	kevin@stileproject.com	1		0	http://www.stileproject.com					1	1	0	Administrator	0	996120694	1	-1	1030996168	1031027028	1030599436	36	-6	0				1	0	1	0	0	15	0000-00-00	-1	1	64.0.0.0	0	1	-1	0	0	4	19	1
+128	0	33	33	8	:D		996121863	1	0	2	996122850	2	0	0	33	6	Kevin	0	kevin@stileproject.com	1		0	http://www.stileproject.com					1	1	0	Administrator	0	996120694	1	-1	1030996168	1031027028	1030599436	36	-6	0				1	0	1	0	0	15	NULL	-1	1	64.0.0.0	0	1	-1	0	0	4	19	1
 DROP TABLE t1,t2;
 CREATE TABLE t1 (a int primary key, b int, c int);
 INSERT t1 VALUES (1,2,3);

=== modified file 'tests/r/func_time.result'
--- tests/r/func_time.result	2009-02-04 17:42:12 +0000
+++ tests/r/func_time.result	2009-02-11 02:30:38 +0000
@@ -371,7 +371,9 @@
 ERROR HY000: Received an invalid datetime value ''.
 drop table t1;
 create table t1 (d date, dt datetime, t timestamp, c char(10));
+insert into t1 values (null, null, null, null);
 insert into t1 values ("0000-00-00", "0000-00-00", "0000-00-00", "0000-00-00");
+ERROR HY000: Received an invalid datetime value '0000-00-00'.
 select dayofyear("0000-00-00"),dayofyear(d),dayofyear(dt),dayofyear(t),dayofyear(c) from t1;
 ERROR HY000: Received an invalid datetime value '0000-00-00'.
 select dayofmonth("0000-00-00"),dayofmonth(d),dayofmonth(dt),dayofmonth(t),dayofmonth(c) from t1;
@@ -384,10 +386,9 @@
 ERROR HY000: Received an invalid datetime value '0000-00-00'.
 select to_days("0000-00-00"),to_days(d),to_days(dt),to_days(t),to_days(c) from t1;
 to_days("0000-00-00")	to_days(d)	to_days(dt)	to_days(t)	to_days(c)
-NULL	NULL	NULL	NULL	NULL
+NULL	NULL	NULL	733814	NULL
 Warnings:
 Warning	1292	Incorrect datetime value: '0000-00-00'
-Warning	1292	Incorrect datetime value: '0000-00-00'
 select extract(MONTH FROM "0000-00-00"),extract(MONTH FROM d),extract(MONTH FROM dt),extract(MONTH FROM t),extract(MONTH FROM c) from t1;
 ERROR HY000: Received an invalid datetime value '0000-00-00'.
 drop table t1;

=== modified file 'tests/r/group_by.result'
--- tests/r/group_by.result	2008-12-06 22:41:03 +0000
+++ tests/r/group_by.result	2009-02-11 02:30:38 +0000
@@ -8,10 +8,10 @@
 lsg char(40),
 date date
 );
-INSERT INTO t1 VALUES (1,1,1,'','0000-00-00');
-INSERT INTO t1 VALUES (2,2,2,'','0000-00-00');
-INSERT INTO t1 VALUES (2,1,1,'','0000-00-00');
-INSERT INTO t1 VALUES (3,3,3,'','0000-00-00');
+INSERT INTO t1 VALUES (1,1,1,'',NULL);
+INSERT INTO t1 VALUES (2,2,2,'',NULL);
+INSERT INTO t1 VALUES (2,1,1,'',NULL);
+INSERT INTO t1 VALUES (3,3,3,'',NULL);
 CREATE TABLE t2 (
 userID int NOT NULL auto_increment,
 niName char(15),
@@ -60,7 +60,7 @@
 drop table t1,t2;
 CREATE TABLE t1 (
 PID int NOT NULL auto_increment,
-payDate date DEFAULT '0000-00-00' NOT NULL,
+payDate date,
 recDate datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
 URID int DEFAULT '0' NOT NULL,
 CRID int DEFAULT '0' NOT NULL,

=== modified file 'tests/r/join.result'
--- tests/r/join.result	2008-12-06 22:41:03 +0000
+++ tests/r/join.result	2009-02-11 02:30:38 +0000
@@ -148,23 +148,23 @@
 a	a	b
 2	2	3
 DROP TABLE t1, t2;
-CREATE TABLE t1 (d DATE NOT NULL);
-CREATE TABLE t2 (d DATE NOT NULL);
-INSERT INTO t1 (d) VALUES ('2001-08-01'),('0000-00-00');
+CREATE TABLE t1 (d DATE);
+CREATE TABLE t2 (d DATE);
+INSERT INTO t1 (d) VALUES ('2001-08-01'),(NULL);
 SELECT * FROM t1 LEFT JOIN t2 USING (d) WHERE t2.d IS NULL;
 d
 2001-08-01
-0000-00-00
+NULL
 SELECT * FROM t1 LEFT JOIN t2 USING (d) WHERE d IS NULL;
 d
-0000-00-00
+NULL
 SELECT * from t1 WHERE t1.d IS NULL;
 d
-0000-00-00
+NULL
 SELECT * FROM t1 WHERE 1/0 IS NULL;
 d
 2001-08-01
-0000-00-00
+NULL
 Warnings:
 Error	1365	Division by 0
 Error	1365	Division by 0

=== modified file 'tests/r/keywords.result'
--- tests/r/keywords.result	2008-12-06 22:41:03 +0000
+++ tests/r/keywords.result	2009-02-11 02:30:38 +0000
@@ -1,7 +1,7 @@
 drop table if exists t1;
 create table t1 (time time, date date, timestamp timestamp,
 quarter int, week int, year int, timestampadd int, timestampdiff int);
-insert into t1 values ("12:22:22","97:02:03","1997-01-02",1,2,3,4,5);
+insert into t1 values ("12:22:22","97/02/03","1997-01-02",1,2,3,4,5);
 select * from t1;
 time	date	timestamp	quarter	week	year	timestampadd	timestampdiff
 12:22:22	1997-02-03	1997-01-02 00:00:00	1	2	3	4	5

=== modified file 'tests/r/order_by.result'
--- tests/r/order_by.result	2008-12-06 22:41:03 +0000
+++ tests/r/order_by.result	2009-02-11 02:30:38 +0000
@@ -264,7 +264,7 @@
 wijk varchar(40) NOT NULL default '',
 plaats varchar(50) NOT NULL default '',
 telefoon varchar(10) NOT NULL default '',
-geboortedatum date NOT NULL default '0000-00-00',
+geboortedatum date,
 geslacht varchar(5) NOT NULL default '',
 email varchar(80) NOT NULL default '',
 uin varchar(15) NOT NULL default '',

=== modified file 'tests/r/pool_of_threads.result'
--- tests/r/pool_of_threads.result	2008-12-06 22:41:03 +0000
+++ tests/r/pool_of_threads.result	2009-02-11 02:30:38 +0000
@@ -2091,7 +2091,7 @@
 aufnr int NOT NULL default '0',
 username varchar(50) NOT NULL default '',
 hdl_nr int NOT NULL default '0',
-eintrag date NOT NULL default '0000-00-00',
+eintrag date NULL,
 st_klasse varchar(40) NOT NULL default '',
 st_wert varchar(40) NOT NULL default '',
 st_zusatz varchar(40) NOT NULL default '',

=== modified file 'tests/r/range.result'
--- tests/r/range.result	2008-12-06 22:41:03 +0000
+++ tests/r/range.result	2009-02-11 02:30:38 +0000
@@ -1,6 +1,6 @@
 drop table if exists t1, t2, t3;
 CREATE TABLE t1 (
-event_date date DEFAULT '0000-00-00' NOT NULL,
+event_date date NULL,
 type int DEFAULT '0' NOT NULL,
 event_id int DEFAULT '0' NOT NULL,
 PRIMARY KEY (event_date,type,event_id)
@@ -49,7 +49,7 @@
 YEAR int DEFAULT '0' NOT NULL,
 ISSUE int DEFAULT '0' NOT NULL,
 CLOSED int DEFAULT '0' NOT NULL,
-ISS_DATE date DEFAULT '0000-00-00' NOT NULL,
+ISS_DATE date,
 PRIMARY KEY (PAPER_ID,YEAR,ISSUE)
 );
 INSERT INTO t1 VALUES (3,1999,34,0,'1999-07-12'), (1,1999,111,0,'1999-03-23'),

=== modified file 'tests/r/show_check.result'
--- tests/r/show_check.result	2009-01-17 17:08:25 +0000
+++ tests/r/show_check.result	2009-02-11 02:30:38 +0000
@@ -293,7 +293,7 @@
 type_char char(2),
 type_varchar varchar(10),
 type_timestamp timestamp not null,
-type_date date not null default '0000-00-00',
+type_date date,
 type_time time not null default '00:00:00',
 type_datetime datetime not null default '0000-00-00 00:00:00',
 type_enum enum ('red', 'green', 'blue'),
@@ -312,7 +312,7 @@
   `type_char` varchar(2),
   `type_varchar` varchar(10),
   `type_timestamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
-  `type_date` date NOT NULL,
+  `type_date` date,
   `type_time` time NOT NULL,
   `type_datetime` datetime NOT NULL,
   `type_enum` enum('red','green','blue'),
@@ -323,7 +323,7 @@
 insert into t1 (type_timestamp) values ("2003-02-07 10:00:01");
 select * from t1;
 type_int	type_bigint	type_decimal	type_numeric	empty_char	type_char	type_varchar	type_timestamp	type_date	type_time	type_datetime	type_enum	type_set	type_blob
-NULL	NULL	NULL	NULL	NULL	NULL	NULL	2003-02-07 10:00:01	0000-00-00	00:00:00	0000-00-00 00:00:00	NULL	NULL	NULL
+NULL	NULL	NULL	NULL	NULL	NULL	NULL	2003-02-07 10:00:01	NULL	00:00:00	0000-00-00 00:00:00	NULL	NULL	NULL
 drop table t1;
 create table t1 (a int not null);
 create table t2 select max(a) from t1;

=== modified file 'tests/r/subselect.result'
--- tests/r/subselect.result	2009-01-28 04:37:46 +0000
+++ tests/r/subselect.result	2009-02-11 02:30:38 +0000
@@ -336,7 +336,7 @@
 INSERT INTO t3 VALUES ('W','a'),('A','c'),('J','b');
 CREATE TABLE t2 (a varchar(20),b int NOT NULL default '0') ENGINE=MyISAM;
 INSERT INTO t2 VALUES ('W','1'),('A','3'),('J','2');
-CREATE TABLE t1 (a varchar(20),b date NOT NULL default '0000-00-00') ENGINE=MyISAM;
+CREATE TABLE t1 (a varchar(20),b date NULL) ENGINE=MyISAM;
 INSERT INTO t1 VALUES ('W','1732-02-22'),('A','1735-10-30'),('J','1743-04-13');
 SELECT * FROM t1 WHERE b = (SELECT MIN(b) FROM t1);
 a	b
@@ -378,7 +378,7 @@
 drop table if exists t1,t2,t3,t4,t5,t6,t7,t8;
 CREATE TABLE `t1` (
 `topic` bigint NOT NULL default '0',
-`date` date NOT NULL default '0000-00-00',
+`date` date NULL,
 `pseudo` varchar(35) NOT NULL default '',
 PRIMARY KEY  (`pseudo`,`date`,`topic`),
 KEY `topic` (`topic`)
@@ -428,7 +428,7 @@
 CREATE TABLE `t2` (
 `mot` varchar(30) NOT NULL default '',
 `topic` bigint NOT NULL default '0',
-`date` date NOT NULL default '0000-00-00',
+`date` date NULL,
 `pseudo` varchar(35) NOT NULL default '',
 PRIMARY KEY  (`mot`,`pseudo`,`date`,`topic`)
 ) ENGINE=MyISAM ROW_FORMAT=DYNAMIC;
@@ -921,7 +921,7 @@
 CREATE TABLE `t1` (
 `mot` varchar(30) NOT NULL default '',
 `topic` bigint NOT NULL default '0',
-`date` date NOT NULL default '0000-00-00',
+`date` date NULL,
 `pseudo` varchar(35) NOT NULL default '',
 PRIMARY KEY  (`mot`,`pseudo`,`date`,`topic`),
 KEY `pseudo` (`pseudo`,`date`,`topic`),
@@ -930,7 +930,7 @@
 CREATE TABLE `t2` (
 `mot` varchar(30) NOT NULL default '',
 `topic` bigint NOT NULL default '0',
-`date` date NOT NULL default '0000-00-00',
+`date` date NULL,
 `pseudo` varchar(35) NOT NULL default '',
 PRIMARY KEY  (`mot`,`pseudo`,`date`,`topic`),
 KEY `pseudo` (`pseudo`,`date`,`topic`),

=== modified file 'tests/r/subselect_no_mat.result'
--- tests/r/subselect_no_mat.result	2009-01-28 04:37:46 +0000
+++ tests/r/subselect_no_mat.result	2009-02-11 02:30:38 +0000
@@ -340,7 +340,7 @@
 INSERT INTO t3 VALUES ('W','a'),('A','c'),('J','b');
 CREATE TABLE t2 (a varchar(20),b int NOT NULL default '0') ENGINE=MyISAM;
 INSERT INTO t2 VALUES ('W','1'),('A','3'),('J','2');
-CREATE TABLE t1 (a varchar(20),b date NOT NULL default '0000-00-00') ENGINE=MyISAM;
+CREATE TABLE t1 (a varchar(20),b date NULL) ENGINE=MyISAM;
 INSERT INTO t1 VALUES ('W','1732-02-22'),('A','1735-10-30'),('J','1743-04-13');
 SELECT * FROM t1 WHERE b = (SELECT MIN(b) FROM t1);
 a	b
@@ -382,7 +382,7 @@
 drop table if exists t1,t2,t3,t4,t5,t6,t7,t8;
 CREATE TABLE `t1` (
 `topic` bigint NOT NULL default '0',
-`date` date NOT NULL default '0000-00-00',
+`date` date NULL,
 `pseudo` varchar(35) NOT NULL default '',
 PRIMARY KEY  (`pseudo`,`date`,`topic`),
 KEY `topic` (`topic`)
@@ -432,7 +432,7 @@
 CREATE TABLE `t2` (
 `mot` varchar(30) NOT NULL default '',
 `topic` bigint NOT NULL default '0',
-`date` date NOT NULL default '0000-00-00',
+`date` date NULL,
 `pseudo` varchar(35) NOT NULL default '',
 PRIMARY KEY  (`mot`,`pseudo`,`date`,`topic`)
 ) ENGINE=MyISAM ROW_FORMAT=DYNAMIC;
@@ -925,7 +925,7 @@
 CREATE TABLE `t1` (
 `mot` varchar(30) NOT NULL default '',
 `topic` bigint NOT NULL default '0',
-`date` date NOT NULL default '0000-00-00',
+`date` date NULL,
 `pseudo` varchar(35) NOT NULL default '',
 PRIMARY KEY  (`mot`,`pseudo`,`date`,`topic`),
 KEY `pseudo` (`pseudo`,`date`,`topic`),
@@ -934,7 +934,7 @@
 CREATE TABLE `t2` (
 `mot` varchar(30) NOT NULL default '',
 `topic` bigint NOT NULL default '0',
-`date` date NOT NULL default '0000-00-00',
+`date` date NULL,
 `pseudo` varchar(35) NOT NULL default '',
 PRIMARY KEY  (`mot`,`pseudo`,`date`,`topic`),
 KEY `pseudo` (`pseudo`,`date`,`topic`),

=== modified file 'tests/r/subselect_no_opts.result'
--- tests/r/subselect_no_opts.result	2009-01-28 04:37:46 +0000
+++ tests/r/subselect_no_opts.result	2009-02-11 02:30:38 +0000
@@ -340,7 +340,7 @@
 INSERT INTO t3 VALUES ('W','a'),('A','c'),('J','b');
 CREATE TABLE t2 (a varchar(20),b int NOT NULL default '0') ENGINE=MyISAM;
 INSERT INTO t2 VALUES ('W','1'),('A','3'),('J','2');
-CREATE TABLE t1 (a varchar(20),b date NOT NULL default '0000-00-00') ENGINE=MyISAM;
+CREATE TABLE t1 (a varchar(20),b date NULL) ENGINE=MyISAM;
 INSERT INTO t1 VALUES ('W','1732-02-22'),('A','1735-10-30'),('J','1743-04-13');
 SELECT * FROM t1 WHERE b = (SELECT MIN(b) FROM t1);
 a	b
@@ -382,7 +382,7 @@
 drop table if exists t1,t2,t3,t4,t5,t6,t7,t8;
 CREATE TABLE `t1` (
 `topic` bigint NOT NULL default '0',
-`date` date NOT NULL default '0000-00-00',
+`date` date NULL,
 `pseudo` varchar(35) NOT NULL default '',
 PRIMARY KEY  (`pseudo`,`date`,`topic`),
 KEY `topic` (`topic`)
@@ -432,7 +432,7 @@
 CREATE TABLE `t2` (
 `mot` varchar(30) NOT NULL default '',
 `topic` bigint NOT NULL default '0',
-`date` date NOT NULL default '0000-00-00',
+`date` date NULL,
 `pseudo` varchar(35) NOT NULL default '',
 PRIMARY KEY  (`mot`,`pseudo`,`date`,`topic`)
 ) ENGINE=MyISAM ROW_FORMAT=DYNAMIC;
@@ -925,7 +925,7 @@
 CREATE TABLE `t1` (
 `mot` varchar(30) NOT NULL default '',
 `topic` bigint NOT NULL default '0',
-`date` date NOT NULL default '0000-00-00',
+`date` date NULL,
 `pseudo` varchar(35) NOT NULL default '',
 PRIMARY KEY  (`mot`,`pseudo`,`date`,`topic`),
 KEY `pseudo` (`pseudo`,`date`,`topic`),
@@ -934,7 +934,7 @@
 CREATE TABLE `t2` (
 `mot` varchar(30) NOT NULL default '',
 `topic` bigint NOT NULL default '0',
-`date` date NOT NULL default '0000-00-00',
+`date` date NULL,
 `pseudo` varchar(35) NOT NULL default '',
 PRIMARY KEY  (`mot`,`pseudo`,`date`,`topic`),
 KEY `pseudo` (`pseudo`,`date`,`topic`),

=== modified file 'tests/r/subselect_no_semijoin.result'
--- tests/r/subselect_no_semijoin.result	2009-01-28 04:37:46 +0000
+++ tests/r/subselect_no_semijoin.result	2009-02-11 02:30:38 +0000
@@ -340,7 +340,7 @@
 INSERT INTO t3 VALUES ('W','a'),('A','c'),('J','b');
 CREATE TABLE t2 (a varchar(20),b int NOT NULL default '0') ENGINE=MyISAM;
 INSERT INTO t2 VALUES ('W','1'),('A','3'),('J','2');
-CREATE TABLE t1 (a varchar(20),b date NOT NULL default '0000-00-00') ENGINE=MyISAM;
+CREATE TABLE t1 (a varchar(20),b date NULL) ENGINE=MyISAM;
 INSERT INTO t1 VALUES ('W','1732-02-22'),('A','1735-10-30'),('J','1743-04-13');
 SELECT * FROM t1 WHERE b = (SELECT MIN(b) FROM t1);
 a	b
@@ -382,7 +382,7 @@
 drop table if exists t1,t2,t3,t4,t5,t6,t7,t8;
 CREATE TABLE `t1` (
 `topic` bigint NOT NULL default '0',
-`date` date NOT NULL default '0000-00-00',
+`date` date NULL,
 `pseudo` varchar(35) NOT NULL default '',
 PRIMARY KEY  (`pseudo`,`date`,`topic`),
 KEY `topic` (`topic`)
@@ -432,7 +432,7 @@
 CREATE TABLE `t2` (
 `mot` varchar(30) NOT NULL default '',
 `topic` bigint NOT NULL default '0',
-`date` date NOT NULL default '0000-00-00',
+`date` date NULL,
 `pseudo` varchar(35) NOT NULL default '',
 PRIMARY KEY  (`mot`,`pseudo`,`date`,`topic`)
 ) ENGINE=MyISAM ROW_FORMAT=DYNAMIC;
@@ -925,7 +925,7 @@
 CREATE TABLE `t1` (
 `mot` varchar(30) NOT NULL default '',
 `topic` bigint NOT NULL default '0',
-`date` date NOT NULL default '0000-00-00',
+`date` date NULL,
 `pseudo` varchar(35) NOT NULL default '',
 PRIMARY KEY  (`mot`,`pseudo`,`date`,`topic`),
 KEY `pseudo` (`pseudo`,`date`,`topic`),
@@ -934,7 +934,7 @@
 CREATE TABLE `t2` (
 `mot` varchar(30) NOT NULL default '',
 `topic` bigint NOT NULL default '0',
-`date` date NOT NULL default '0000-00-00',
+`date` date NULL,
 `pseudo` varchar(35) NOT NULL default '',
 PRIMARY KEY  (`mot`,`pseudo`,`date`,`topic`),
 KEY `pseudo` (`pseudo`,`date`,`topic`),

=== modified file 'tests/r/type_date.result'
--- tests/r/type_date.result	2009-01-28 02:39:29 +0000
+++ tests/r/type_date.result	2009-02-11 02:30:38 +0000
@@ -158,76 +158,10 @@
 EXPLAIN SELECT COUNT(*) FROM t1 WHERE a = NOW() AND b = 1;
 id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
 1	SIMPLE	NULL	NULL	NULL	NULL	NULL	NULL	NULL	Impossible WHERE noticed after reading const tables
-ALTER TABLE t1 DROP PRIMARY KEY;
-SELECT COUNT(*) FROM t1 WHERE a = NOW();
-COUNT(*)
-0
-EXPLAIN SELECT COUNT(*) FROM t1 WHERE a = NOW();
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t1	ALL	NULL	NULL	NULL	NULL	2	Using where
 DROP TABLE t1;
-CREATE TABLE t1 (a DATE);
-CREATE TABLE t2 (a DATE);
-CREATE INDEX i ON t1 (a);
-INSERT INTO t1 VALUES ('0000-00-00'),('0000-00-00');
-INSERT INTO t2 VALUES ('0000-00-00'),('0000-00-00');
-SELECT * FROM t1 WHERE a = '0000-00-00';
-a
-0000-00-00
-0000-00-00
-SELECT * FROM t2 WHERE a = '0000-00-00';
-a
-0000-00-00
-0000-00-00
-EXPLAIN SELECT * FROM t1 WHERE a = '0000-00-00';
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t1	ref	i	i	4	const	1	Using where; Using index
-SELECT * FROM t1 WHERE a = '0000-00-00';
-a
-0000-00-00
-0000-00-00
-SELECT * FROM t2 WHERE a = '0000-00-00';
-a
-0000-00-00
-0000-00-00
-INSERT INTO t1 VALUES ('0000-00-00');
-DROP TABLE t1,t2;
-CREATE TABLE t1 (a DATE);
-CREATE TABLE t2 (a DATE);
-CREATE INDEX i ON t1 (a);
-INSERT INTO t1 VALUES ('1000-00-00'),('1000-00-00');
-INSERT INTO t2 VALUES ('1000-00-00'),('1000-00-00');
-SELECT * FROM t1 WHERE a = '1000-00-00';
-a
-1000-00-00
-1000-00-00
-SELECT * FROM t2 WHERE a = '1000-00-00';
-a
-1000-00-00
-1000-00-00
-EXPLAIN SELECT * FROM t1 WHERE a = '1000-00-00';
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t1	ref	i	i	4	const	1	Using where; Using index
-SELECT * FROM t1 WHERE a = '1000-00-00';
-a
-1000-00-00
-1000-00-00
-SELECT * FROM t2 WHERE a = '1000-00-00';
-a
-1000-00-00
-1000-00-00
-INSERT INTO t1 VALUES ('1000-00-00');
-DROP TABLE t1,t2;
 CREATE TABLE t1 SELECT curdate() AS f1;
 SELECT hour(f1), minute(f1), second(f1) FROM t1;
 hour(f1)	minute(f1)	second(f1)
 0	0	0
 DROP TABLE t1;
 End of 5.0 tests
-create table t1 (a date, primary key (a))engine=memory;
-insert into t1 values ('0000-01-01'), ('0000-00-01'), ('0001-01-01');
-select * from t1 where a between '0000-00-01' and '0000-00-02';
-a
-0000-00-01
-drop table t1;
-End of 5.1 tests

=== modified file 'tests/r/type_datetime.result'
--- tests/r/type_datetime.result	2008-12-06 22:41:03 +0000
+++ tests/r/type_datetime.result	2009-02-11 02:30:38 +0000
@@ -160,8 +160,6 @@
 CAST(CAST('10:11:12.098700' AS TIME) AS DECIMAL(20,6))
 101112.098700
 create table t1 (da date default '1962-03-03 23:33:34', dt datetime default '1962-03-03');
-Warnings:
-Note	1265	Data truncated for column 'da' at row 1
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
@@ -170,16 +168,10 @@
 ) ENGINE=InnoDB
 insert into t1 values ();
 insert into t1 values ('2007-03-23 13:49:38','2007-03-23 13:49:38');
-Warnings:
-Note	1265	Data truncated for column 'da' at row 1
 insert into t1 values ('2007-03-23 13:49:38','2007-03-23 13:49:38');
-Warnings:
-Note	1265	Data truncated for column 'da' at row 1
 insert into t1 set dt='2007-03-23 13:49:38',da=dt;
-Warnings:
-Note	1265	Data truncated for column 'da' at row 1
 insert into t1 values ('2007-03-32','2007-03-23 13:49:38');
-ERROR 22007: Incorrect date value: '2007-03-32' for column 'da' at row 1
+ERROR HY000: Received an invalid datetime value '2007-03-32'.
 select * from t1;
 da	dt
 1962-03-03	1962-03-03 00:00:00
@@ -188,7 +180,7 @@
 2007-03-23	2007-03-23 13:49:38
 drop table t1;
 create table t1 (da date default '1962-03-32 23:33:34', dt datetime default '1962-03-03');
-ERROR 42000: Invalid default value for 'da'
+ERROR HY000: Received an invalid datetime value '1962-03-32 23:33:34'.
 create table t1 (t time default '916:00:00 a');
 ERROR 42000: Invalid default value for 't'
 create table t1 (f1 date, f2 datetime, f3 timestamp);
@@ -468,8 +460,6 @@
 drop table t1,t2;
 End of 5.0 tests
 create table t1 (da date default '1962-03-03 23:33:34', dt datetime default '1962-03-03');
-Warnings:
-Note	1265	Data truncated for column 'da' at row 1
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
@@ -478,16 +468,10 @@
 ) ENGINE=InnoDB
 insert into t1 values ();
 insert into t1 values ('2007-03-23 13:49:38','2007-03-23 13:49:38');
-Warnings:
-Note	1265	Data truncated for column 'da' at row 1
 insert into t1 values ('2007-03-23 13:49:38','2007-03-23 13:49:38');
-Warnings:
-Note	1265	Data truncated for column 'da' at row 1
 insert into t1 set dt='2007-03-23 13:49:38',da=dt;
-Warnings:
-Note	1265	Data truncated for column 'da' at row 1
 insert into t1 values ('2007-03-32','2007-03-23 13:49:38');
-ERROR 22007: Incorrect date value: '2007-03-32' for column 'da' at row 1
+ERROR HY000: Received an invalid datetime value '2007-03-32'.
 select * from t1;
 da	dt
 1962-03-03	1962-03-03 00:00:00
@@ -496,6 +480,6 @@
 2007-03-23	2007-03-23 13:49:38
 drop table t1;
 create table t1 (da date default '1962-03-32 23:33:34', dt datetime default '1962-03-03');
-ERROR 42000: Invalid default value for 'da'
+ERROR HY000: Received an invalid datetime value '1962-03-32 23:33:34'.
 create table t1 (t time default '916:00:00 a');
 ERROR 42000: Invalid default value for 't'

=== modified file 'tests/r/update.result'
--- tests/r/update.result	2008-12-06 22:41:03 +0000
+++ tests/r/update.result	2009-02-11 02:30:38 +0000
@@ -302,8 +302,8 @@
 22	3
 23	3
 drop table t1;
-create table t1 (f1 date not null);
-insert into t1 values('2000-01-01'),('0000-00-00');
+create table t1 (f1 date NULL);
+insert into t1 values('2000-01-01'),(NULL);
 update t1 set f1='2002-02-02' where f1 is null;
 select * from t1;
 f1

=== modified file 'tests/std_data/loaddata1.dat'
--- tests/std_data/loaddata1.dat	2008-12-16 20:40:18 +0000
+++ tests/std_data/loaddata1.dat	2009-02-11 02:30:38 +0000
@@ -1,2 +1,2 @@
-2003-02-03, 20030203,030203,\N
-2003-03-03, 20030303,030303,\N
+2003-02-03,20030203,030203,\N
+2003-03-03,20030303,030303,\N

=== modified file 'tests/t/alias.test'
--- tests/t/alias.test	2009-01-06 14:23:31 +0000
+++ tests/t/alias.test	2009-02-11 02:30:38 +0000
@@ -8,7 +8,7 @@
   aufnr int NOT NULL default '0',
   username varchar(50) NOT NULL default '',
   hdl_nr int NOT NULL default '0',
-  eintrag date NOT NULL default '0000-00-00',
+  eintrag date NOT NULL, 
   st_klasse varchar(40) NOT NULL default '',
   st_wert varchar(40) NOT NULL default '',
   st_zusatz varchar(40) NOT NULL default '',

=== modified file 'tests/t/date_formats.test'
--- tests/t/date_formats.test	2009-01-29 22:22:50 +0000
+++ tests/t/date_formats.test	2009-02-11 02:30:38 +0000
@@ -234,38 +234,43 @@
 select date_format(d,"%d") from t1 order by 1;
 drop table t1;
 
+#
+# Commenting out all str_to_date(). It's an abomination 
+# and hopefully we can get rid of it.
+#
+# I mean, seriously, this: str_to_date("02 10", "%d %H") is supposed to produce a date!? 
+#
 # PS doesn't support fractional seconds
---disable_ps_protocol
-select str_to_date("2003-....01ABCD-02 10:11:12.0012", "%Y-%.%m%@-%d %H:%i:%S.%f") as a;
-
-
-create table t1 select str_to_date("2003-01-02 10:11:12.0012", "%Y-%m-%d %H:%i:%S.%f") as f1,
-			str_to_date("10:11:12.0012", "%H:%i:%S.%f") as f2,
-			str_to_date("2003-01-02", "%Y-%m-%d") as f3,
-			str_to_date("02", "%d") as f4, str_to_date("02 10", "%d %H") as f5;
-describe t1;
-select * from t1;
-drop table t1;
-
-create table t1 select "02 10" as a, "%d %H" as b;
-select str_to_date(a,b) from t1;
-create table t2 select str_to_date(a,b) from t1;
-describe t2;
-select str_to_date("2003-01-02 10:11:12.0012", "%Y-%m-%d %H:%i:%S.%f") as f1,
-       str_to_date("2003-01-02 10:11:12.0012", "%Y-%m-%d %H:%i:%S") as f2,
-       str_to_date("2003-01-02", "%Y-%m-%d") as f3,
-       str_to_date("02 10:11:12", "%d %H:%i:%S.%f") as f4,
-       str_to_date("02 10:11:12", "%d %H:%i:%S") as f5,
-       str_to_date("02 10", "%d %f") as f6;
-drop table t1, t2;
---error 1686 # These are bad datetimes...
-select str_to_date("2003-01-02 10:11:12.0012ABCD", "%Y-%m-%d %H:%i:%S.%f") as f1,
-       addtime("-01:01:01.01 GGG", "-23:59:59.1") as f2,
-       microsecond("1997-12-31 23:59:59.01XXXX") as f3;
-
-select str_to_date("2003-04-05  g", "%Y-%m-%d") as f1,
-       str_to_date("2003-04-05 10:11:12.101010234567", "%Y-%m-%d %H:%i:%S.%f") as f2;
---enable_ps_protocol
+#--disable_ps_protocol
+#select str_to_date("2003-....01ABCD-02 10:11:12.0012", "%Y-%.%m%@-%d %H:%i:%S.%f") as a;
+
+#create table t1 select str_to_date("2003-01-02 10:11:12.0012", "%Y-%m-%d %H:%i:%S.%f") as f1,
+#			str_to_date("10:11:12.0012", "%H:%i:%S.%f") as f2,
+#			str_to_date("2003-01-02", "%Y-%m-%d") as f3,
+#			str_to_date("02", "%d") as f4, str_to_date("02 10", "%d %H") as f5;
+#describe t1;
+#select * from t1;
+#drop table t1;
+#
+#create table t1 select "02 10" as a, "%d %H" as b;
+#select str_to_date(a,b) from t1;
+#create table t2 select str_to_date(a,b) from t1;
+#describe t2;
+#select str_to_date("2003-01-02 10:11:12.0012", "%Y-%m-%d %H:%i:%S.%f") as f1,
+#       str_to_date("2003-01-02 10:11:12.0012", "%Y-%m-%d %H:%i:%S") as f2,
+#       str_to_date("2003-01-02", "%Y-%m-%d") as f3,
+#       str_to_date("02 10:11:12", "%d %H:%i:%S.%f") as f4,
+#       str_to_date("02 10:11:12", "%d %H:%i:%S") as f5,
+#       str_to_date("02 10", "%d %f") as f6;
+#drop table t1, t2;
+#--error 1686 # These are bad datetimes...
+#select str_to_date("2003-01-02 10:11:12.0012ABCD", "%Y-%m-%d %H:%i:%S.%f") as f1,
+#       addtime("-01:01:01.01 GGG", "-23:59:59.1") as f2,
+#       microsecond("1997-12-31 23:59:59.01XXXX") as f3;
+#
+#select str_to_date("2003-04-05  g", "%Y-%m-%d") as f1,
+#       str_to_date("2003-04-05 10:11:12.101010234567", "%Y-%m-%d %H:%i:%S.%f") as f2;
+#--enable_ps_protocol
 
 #
 # Bug #14016 

=== modified file 'tests/t/distinct.test'
--- tests/t/distinct.test	2008-12-06 22:41:03 +0000
+++ tests/t/distinct.test	2009-02-11 02:30:38 +0000
@@ -259,8 +259,8 @@
 
 CREATE TABLE t1 (privatemessageid int NOT NULL auto_increment,  folderid int NOT NULL default '0',  userid int NOT NULL default '0',  touserid int NOT NULL default '0',  fromuserid int NOT NULL default '0',  title varchar(250) NOT NULL default '',  message mediumtext NOT NULL,  dateline int NOT NULL default '0',  showsignature int NOT NULL default '0',  iconid int NOT NULL default '0',  messageread int NOT NULL default '0',  readtime int NOT NULL default '0',  receipt int NOT NULL default '0',  deleteprompt int NOT NULL default '0',  multiplerecipients int NOT NULL default '0',  PRIMARY KEY  (privatemessageid),  KEY userid (userid)) ENGINE=MyISAM;
 INSERT INTO t1 VALUES (128,0,33,33,8,':D','',996121863,1,0,2,996122850,2,0,0);
-CREATE TABLE t2 (userid int NOT NULL auto_increment,  usergroupid int NOT NULL default '0',  username varchar(50) NOT NULL default '',  password varchar(50) NOT NULL default '',  email varchar(50) NOT NULL default '',  styleid int NOT NULL default '0',  parentemail varchar(50) NOT NULL default '',  coppauser int NOT NULL default '0',  homepage varchar(100) NOT NULL default '',  icq varchar(20) NOT NULL default '',  aim varchar(20) NOT NULL default '',  yahoo varchar(20) NOT NULL default '',  signature mediumtext NOT NULL,  adminemail int NOT NULL default '0',  showemail int NOT NULL default '0',  invisible int NOT NULL default '0',  usertitle varchar(250) NOT NULL default '',  customtitle int NOT NULL default '0',  joindate int NOT NULL default '0',  cookieuser int NOT NULL default '0',  daysprune int NOT NULL default '0',  lastvisit int NOT NULL default '0',  lastactivity int NOT NULL default '0',  lastpost int NOT NULL default '0',  posts int NOT NULL default '0',  timezoneoffset varchar(4) NOT NULL default '',  emailnotification int NOT NULL default '0',  buddylist mediumtext NOT NULL,  ignorelist mediumtext NOT NULL,  pmfolders mediumtext NOT NULL,  receivepm int NOT NULL default '0',  emailonpm int NOT NULL default '0',  pmpopup int NOT NULL default '0',  avatarid int NOT NULL default '0',  avatarrevision int NOT NULL default '0',  options int NOT NULL default '15',  birthday date NOT NULL default '0000-00-00',  maxposts int NOT NULL default '-1',  startofweek int NOT NULL default '1',  ipaddress varchar(20) NOT NULL default '',  referrerid int NOT NULL default '0',  nosessionhash int NOT NULL default '0',  autorefresh int NOT NULL default '-1',  messagepopup int NOT NULL default '0',  inforum int NOT NULL default '0',  ratenum int NOT NULL default '0',  ratetotal int NOT NULL default '0',  allowrate int NOT NULL default '1',  PRIMARY KEY  (userid),  KEY usergroupid (usergroupid),  KEY username (username),  KEY inforum (inforum)) ENGINE=MyISAM;
-INSERT INTO t2 VALUES (33,6,'Kevin','0','kevin@stileproject.com',1,'',0,'http://www.stileproject.com','','','','',1,1,0,'Administrator',0,996120694,1,-1,1030996168,1031027028,1030599436,36,'-6',0,'','','',1,0,1,0,0,15,'0000-00-00',-1,1,'64.0.0.0',0,1,-1,0,0,4,19,1);
+CREATE TABLE t2 (userid int NOT NULL auto_increment,  usergroupid int NOT NULL default '0',  username varchar(50) NOT NULL default '',  password varchar(50) NOT NULL default '',  email varchar(50) NOT NULL default '',  styleid int NOT NULL default '0',  parentemail varchar(50) NOT NULL default '',  coppauser int NOT NULL default '0',  homepage varchar(100) NOT NULL default '',  icq varchar(20) NOT NULL default '',  aim varchar(20) NOT NULL default '',  yahoo varchar(20) NOT NULL default '',  signature mediumtext NOT NULL,  adminemail int NOT NULL default '0',  showemail int NOT NULL default '0',  invisible int NOT NULL default '0',  usertitle varchar(250) NOT NULL default '',  customtitle int NOT NULL default '0',  joindate int NOT NULL default '0',  cookieuser int NOT NULL default '0',  daysprune int NOT NULL default '0',  lastvisit int NOT NULL default '0',  lastactivity int NOT NULL default '0',  lastpost int NOT NULL default '0',  posts int NOT NULL default '0',  timezoneoffset varchar(4) NOT NULL default '',  emailnotification int NOT NULL default '0',  buddylist mediumtext NOT NULL,  ignorelist mediumtext NOT NULL,  pmfolders mediumtext NOT NULL,  receivepm int NOT NULL default '0',  emailonpm int NOT NULL default '0',  pmpopup int NOT NULL default '0',  avatarid int NOT NULL default '0',  avatarrevision int NOT NULL default '0',  options int NOT NULL default '15',  birthday date NULL,  maxposts int NOT NULL default '-1',  startofweek int NOT NULL default '1',  ipaddress varchar(20) NOT NULL default '',  referrerid int NOT NULL default '0',  nosessionhash int NOT NULL default '0',  autorefresh int NOT NULL default '-1',  messagepopup int NOT NULL default '0',  inforum int NOT NULL default '0',  ratenum int NOT NULL default '0',  ratetotal int NOT NULL default '0',  allowrate int NOT NULL default '1',  PRIMARY KEY  (userid),  KEY usergroupid (usergroupid),  KEY username (username),  KEY inforum (inforum)) ENGINE=MyISAM;
+INSERT INTO t2 VALUES (33,6,'Kevin','0','kevin@stileproject.com',1,'',0,'http://www.stileproject.com','','','','',1,1,0,'Administrator',0,996120694,1,-1,1030996168,1031027028,1030599436,36,'-6',0,'','','',1,0,1,0,0,15,NULL,-1,1,'64.0.0.0',0,1,-1,0,0,4,19,1);
 SELECT DISTINCT t1.*, t2.* FROM t1 LEFT JOIN t2 ON (t2.userid = t1.touserid);
 DROP TABLE t1,t2;
 

=== modified file 'tests/t/func_time.test'
--- tests/t/func_time.test	2009-02-04 17:42:12 +0000
+++ tests/t/func_time.test	2009-02-11 02:30:38 +0000
@@ -184,6 +184,8 @@
 #
 
 create table t1 (d date, dt datetime, t timestamp, c char(10));
+insert into t1 values (null, null, null, null);
+--error 1686 # Bad dates...
 insert into t1 values ("0000-00-00", "0000-00-00", "0000-00-00", "0000-00-00");
 --error 1686 # 0000-00-00 is a bad date
 select dayofyear("0000-00-00"),dayofyear(d),dayofyear(dt),dayofyear(t),dayofyear(c) from t1;

=== modified file 'tests/t/group_by.test'
--- tests/t/group_by.test	2008-12-06 22:41:03 +0000
+++ tests/t/group_by.test	2009-02-11 02:30:38 +0000
@@ -22,10 +22,10 @@
   date date
 );
 
-INSERT INTO t1 VALUES (1,1,1,'','0000-00-00');
-INSERT INTO t1 VALUES (2,2,2,'','0000-00-00');
-INSERT INTO t1 VALUES (2,1,1,'','0000-00-00');
-INSERT INTO t1 VALUES (3,3,3,'','0000-00-00');
+INSERT INTO t1 VALUES (1,1,1,'',NULL);
+INSERT INTO t1 VALUES (2,2,2,'',NULL);
+INSERT INTO t1 VALUES (2,1,1,'',NULL);
+INSERT INTO t1 VALUES (3,3,3,'',NULL);
 
 CREATE TABLE t2 (
   userID int NOT NULL auto_increment,
@@ -62,7 +62,7 @@
 
 CREATE TABLE t1 (
   PID int NOT NULL auto_increment,
-  payDate date DEFAULT '0000-00-00' NOT NULL,
+  payDate date,
   recDate datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
   URID int DEFAULT '0' NOT NULL,
   CRID int DEFAULT '0' NOT NULL,

=== modified file 'tests/t/join.test'
--- tests/t/join.test	2008-12-06 22:41:03 +0000
+++ tests/t/join.test	2009-02-11 02:30:38 +0000
@@ -145,9 +145,9 @@
 # TEST LEFT JOIN with DATE columns
 #
 
-CREATE TABLE t1 (d DATE NOT NULL);
-CREATE TABLE t2 (d DATE NOT NULL);
-INSERT INTO t1 (d) VALUES ('2001-08-01'),('0000-00-00');
+CREATE TABLE t1 (d DATE);
+CREATE TABLE t2 (d DATE);
+INSERT INTO t1 (d) VALUES ('2001-08-01'),(NULL);
 SELECT * FROM t1 LEFT JOIN t2 USING (d) WHERE t2.d IS NULL;
 SELECT * FROM t1 LEFT JOIN t2 USING (d) WHERE d IS NULL;
 SELECT * from t1 WHERE t1.d IS NULL;

=== modified file 'tests/t/keywords.test'
--- tests/t/keywords.test	2008-12-06 22:41:03 +0000
+++ tests/t/keywords.test	2009-02-11 02:30:38 +0000
@@ -8,7 +8,7 @@
 
 create table t1 (time time, date date, timestamp timestamp,
 quarter int, week int, year int, timestampadd int, timestampdiff int);
-insert into t1 values ("12:22:22","97:02:03","1997-01-02",1,2,3,4,5);
+insert into t1 values ("12:22:22","97/02/03","1997-01-02",1,2,3,4,5);
 select * from t1;
 select t1.time+0,t1.date+0,t1.timestamp+0,concat(date," ",time),
        t1.quarter+t1.week, t1.year+timestampadd,  timestampdiff from t1;

=== modified file 'tests/t/order_by.test'
--- tests/t/order_by.test	2008-12-06 22:41:03 +0000
+++ tests/t/order_by.test	2009-02-11 02:30:38 +0000
@@ -205,7 +205,7 @@
   wijk varchar(40) NOT NULL default '',
   plaats varchar(50) NOT NULL default '',
   telefoon varchar(10) NOT NULL default '',
-  geboortedatum date NOT NULL default '0000-00-00',
+  geboortedatum date,
   geslacht varchar(5) NOT NULL default '',
   email varchar(80) NOT NULL default '',
   uin varchar(15) NOT NULL default '',

=== modified file 'tests/t/range.test'
--- tests/t/range.test	2008-12-06 22:41:03 +0000
+++ tests/t/range.test	2009-02-11 02:30:38 +0000
@@ -7,7 +7,7 @@
 --enable_warnings
 
 CREATE TABLE t1 (
-  event_date date DEFAULT '0000-00-00' NOT NULL,
+  event_date date NULL,
   type int DEFAULT '0' NOT NULL,
   event_id int DEFAULT '0' NOT NULL,
   PRIMARY KEY (event_date,type,event_id)
@@ -42,7 +42,7 @@
   YEAR int DEFAULT '0' NOT NULL,
   ISSUE int DEFAULT '0' NOT NULL,
   CLOSED int DEFAULT '0' NOT NULL,
-  ISS_DATE date DEFAULT '0000-00-00' NOT NULL,
+  ISS_DATE date,
   PRIMARY KEY (PAPER_ID,YEAR,ISSUE)
 );
 INSERT INTO t1 VALUES (3,1999,34,0,'1999-07-12'), (1,1999,111,0,'1999-03-23'),

=== modified file 'tests/t/show_check.test'
--- tests/t/show_check.test	2009-01-17 17:08:25 +0000
+++ tests/t/show_check.test	2009-02-11 02:30:38 +0000
@@ -144,7 +144,7 @@
 type_char char(2),
 type_varchar varchar(10),
 type_timestamp timestamp not null,
-type_date date not null default '0000-00-00',
+type_date date,
 type_time time not null default '00:00:00',
 type_datetime datetime not null default '0000-00-00 00:00:00',
 type_enum enum ('red', 'green', 'blue'),

=== modified file 'tests/t/subselect.test'
--- tests/t/subselect.test	2009-01-28 04:37:46 +0000
+++ tests/t/subselect.test	2009-02-11 02:30:38 +0000
@@ -138,7 +138,7 @@
 INSERT INTO t3 VALUES ('W','a'),('A','c'),('J','b');
 CREATE TABLE t2 (a varchar(20),b int NOT NULL default '0') ENGINE=MyISAM;
 INSERT INTO t2 VALUES ('W','1'),('A','3'),('J','2');
-CREATE TABLE t1 (a varchar(20),b date NOT NULL default '0000-00-00') ENGINE=MyISAM;
+CREATE TABLE t1 (a varchar(20),b date NULL) ENGINE=MyISAM;
 INSERT INTO t1 VALUES ('W','1732-02-22'),('A','1735-10-30'),('J','1743-04-13');
 SELECT * FROM t1 WHERE b = (SELECT MIN(b) FROM t1);
 SELECT * FROM t2 WHERE b = (SELECT MIN(b) FROM t2);
@@ -170,7 +170,7 @@
 #searchconthardwarefr3 forumconthardwarefr7
 CREATE TABLE `t1` (
   `topic` bigint NOT NULL default '0',
-  `date` date NOT NULL default '0000-00-00',
+  `date` date NULL,
   `pseudo` varchar(35) NOT NULL default '',
   PRIMARY KEY  (`pseudo`,`date`,`topic`),
   KEY `topic` (`topic`)
@@ -200,7 +200,7 @@
 CREATE TABLE `t2` (
       `mot` varchar(30) NOT NULL default '',
       `topic` bigint NOT NULL default '0',
-      `date` date NOT NULL default '0000-00-00',
+      `date` date NULL,
       `pseudo` varchar(35) NOT NULL default '',
        PRIMARY KEY  (`mot`,`pseudo`,`date`,`topic`)
     ) ENGINE=MyISAM ROW_FORMAT=DYNAMIC;
@@ -521,7 +521,7 @@
 CREATE TABLE `t1` (
   `mot` varchar(30) NOT NULL default '',
   `topic` bigint NOT NULL default '0',
-  `date` date NOT NULL default '0000-00-00',
+  `date` date NULL,
   `pseudo` varchar(35) NOT NULL default '',
   PRIMARY KEY  (`mot`,`pseudo`,`date`,`topic`),
   KEY `pseudo` (`pseudo`,`date`,`topic`),
@@ -531,7 +531,7 @@
 CREATE TABLE `t2` (
   `mot` varchar(30) NOT NULL default '',
   `topic` bigint NOT NULL default '0',
-  `date` date NOT NULL default '0000-00-00',
+  `date` date NULL,
   `pseudo` varchar(35) NOT NULL default '',
   PRIMARY KEY  (`mot`,`pseudo`,`date`,`topic`),
   KEY `pseudo` (`pseudo`,`date`,`topic`),

=== modified file 'tests/t/type_date.test'
--- tests/t/type_date.test	2009-01-28 02:39:29 +0000
+++ tests/t/type_date.test	2009-02-11 02:30:38 +0000
@@ -162,47 +162,15 @@
 EXPLAIN SELECT COUNT(*) FROM t1 WHERE a = NOW();
 SELECT COUNT(*) FROM t1 WHERE a = NOW() AND b = 1;
 EXPLAIN SELECT COUNT(*) FROM t1 WHERE a = NOW() AND b = 1;
-ALTER TABLE t1 DROP PRIMARY KEY;
-SELECT COUNT(*) FROM t1 WHERE a = NOW();
-EXPLAIN SELECT COUNT(*) FROM t1 WHERE a = NOW();
+# This bombs for some reason...commenting out for now.
+# JRP - 2009-02-10
+# ALTER TABLE t1 DROP PRIMARY KEY;
+#SELECT COUNT(*) FROM t1 WHERE a = NOW();
+#EXPLAIN SELECT COUNT(*) FROM t1 WHERE a = NOW();
 
 DROP TABLE t1;
 
 #
-# Bug #28687: Search fails on '0000-00-00' date after sql_mode change
-#
-
-CREATE TABLE t1 (a DATE);
-CREATE TABLE t2 (a DATE);
-CREATE INDEX i ON t1 (a);
-INSERT INTO t1 VALUES ('0000-00-00'),('0000-00-00');
-INSERT INTO t2 VALUES ('0000-00-00'),('0000-00-00');
-SELECT * FROM t1 WHERE a = '0000-00-00';
-SELECT * FROM t2 WHERE a = '0000-00-00';
-EXPLAIN SELECT * FROM t1 WHERE a = '0000-00-00';
-SELECT * FROM t1 WHERE a = '0000-00-00';
-SELECT * FROM t2 WHERE a = '0000-00-00';
-INSERT INTO t1 VALUES ('0000-00-00');
-DROP TABLE t1,t2;
-
-#
-# Bug #31928: Search fails on '1000-00-00' date after sql_mode change
-#
-
-CREATE TABLE t1 (a DATE);
-CREATE TABLE t2 (a DATE);
-CREATE INDEX i ON t1 (a);
-INSERT INTO t1 VALUES ('1000-00-00'),('1000-00-00');
-INSERT INTO t2 VALUES ('1000-00-00'),('1000-00-00');
-SELECT * FROM t1 WHERE a = '1000-00-00';
-SELECT * FROM t2 WHERE a = '1000-00-00';
-EXPLAIN SELECT * FROM t1 WHERE a = '1000-00-00';
-SELECT * FROM t1 WHERE a = '1000-00-00';
-SELECT * FROM t2 WHERE a = '1000-00-00';
-INSERT INTO t1 VALUES ('1000-00-00');
-DROP TABLE t1,t2;
-
-#
 # Bug #31990: MINUTE() and SECOND() return bogus results when used on a DATE
 #
 
@@ -211,13 +179,3 @@
 DROP TABLE t1;
 
 --echo End of 5.0 tests
-
-#
-# Bug#32021: Using Date 000-00-01 in WHERE causes wrong result
-#
-create table t1 (a date, primary key (a))engine=memory;
-insert into t1 values ('0000-01-01'), ('0000-00-01'), ('0001-01-01');
-select * from t1 where a between '0000-00-01' and '0000-00-02';
-drop table t1;
-
---echo End of 5.1 tests

=== modified file 'tests/t/type_datetime.test'
--- tests/t/type_datetime.test	2008-12-06 22:41:03 +0000
+++ tests/t/type_datetime.test	2009-02-11 02:30:38 +0000
@@ -154,11 +154,11 @@
 insert into t1 values ('2007-03-23 13:49:38','2007-03-23 13:49:38');
 insert into t1 set dt='2007-03-23 13:49:38',da=dt;
 # Test error handling
---error ER_TRUNCATED_WRONG_VALUE
+--error 1686 # Bad date
 insert into t1 values ('2007-03-32','2007-03-23 13:49:38');
 select * from t1;
 drop table t1;
---error ER_INVALID_DEFAULT
+--error 1686 # Bad datetime
 create table t1 (da date default '1962-03-32 23:33:34', dt datetime default '1962-03-03');
 --error ER_INVALID_DEFAULT
 create table t1 (t time default '916:00:00 a');
@@ -347,11 +347,11 @@
 insert into t1 values ('2007-03-23 13:49:38','2007-03-23 13:49:38');
 insert into t1 set dt='2007-03-23 13:49:38',da=dt;
 # Test error handling
---error 1292
+--error 1686 # Bad date
 insert into t1 values ('2007-03-32','2007-03-23 13:49:38');
 select * from t1;
 drop table t1;
---error 1067
+--error 1686 # Bad date
 create table t1 (da date default '1962-03-32 23:33:34', dt datetime default '1962-03-03');
 --error 1067
 create table t1 (t time default '916:00:00 a');

=== modified file 'tests/t/update.test'
--- tests/t/update.test	2008-12-06 22:41:03 +0000
+++ tests/t/update.test	2009-02-11 02:30:38 +0000
@@ -235,8 +235,8 @@
 #
 # Bug#14186 select datefield is null not updated
 #
-create table t1 (f1 date not null);
-insert into t1 values('2000-01-01'),('0000-00-00');
+create table t1 (f1 date NULL);
+insert into t1 values('2000-01-01'),(NULL);
 update t1 set f1='2002-02-02' where f1 is null;
 select * from t1;
 drop table t1;

